summaryrefslogtreecommitdiffstats
path: root/src/kile/kileproject.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kile/kileproject.cpp')
-rw-r--r--src/kile/kileproject.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/kile/kileproject.cpp b/src/kile/kileproject.cpp
index 9004be2..64b864e 100644
--- a/src/kile/kileproject.cpp
+++ b/src/kile/kileproject.cpp
@@ -75,7 +75,7 @@ void KileProjectItem::setParent(KileProjectItem * item)
{
m_parent = item;
//update tqparent info
if (m_parent)
{
if (m_parent->firstChild())
@@ -507,7 +507,7 @@ void KileProject::buildProjectTree()
{
KILE_DEBUG() << "==KileProject::buildProjectTree==========================" << endl;
//determine the tqparent doc for each item (TODO:an item can only have one tqparent, not necessarily true for LaTeX docs)
const TQStringList *deps;
TQString dep;
@@ -522,7 +522,7 @@ void KileProject::buildProjectTree()
++it;
}
//use the dependencies list of the documentinfo object to determine the tqparent
it.toFirst();
while (it.current())
{
@@ -542,7 +542,7 @@ void KileProject::buildProjectTree()
url = KileInfo::checkOtherPaths(m_baseurl,dep,KileInfo::bibinputs);
itm = item(url);
- if (itm && (itm->tqparent() == 0))
+ if (itm && (itm->parent() == 0))
itm->setParent(*it);
}
}
@@ -550,12 +550,12 @@ void KileProject::buildProjectTree()
++it;
}
//make a list of all the root items (items with tqparent == 0)
m_rootItems.clear();
it.toFirst();
while (it.current())
{
- if ((*it)->tqparent() == 0) m_rootItems.append(*it);
+ if ((*it)->parent() == 0) m_rootItems.append(*it);
++it;
}
@@ -728,10 +728,10 @@ bool KileProject::contains(const KileDocument::Info *info)
KileProjectItem *KileProject::rootItem(KileProjectItem *item) const
{
//find the root item (i.e. the eldest tqparent)
KileProjectItem *root = item;
- while ( root->tqparent() != 0)
- root = root->tqparent();
+ while ( root->parent() != 0)
+ root = root->parent();
//check if this root item is a LaTeX root
if ( root->getInfo() )
@@ -75,7 +75,7 @@ void KileProjectItem::setParent(KileProjectItem * item)
{
m_parent = item;
- //update tqparent info
+ //update parent info
if (m_parent)
{
@@ -507,7 +507,7 @@ void KileProject::buildProjectTree()
{
KILE_DEBUG() << "==KileProject::buildProjectTree==========================" << endl;
- //determine the tqparent doc for each item (TODO:an item can only have one tqparent, not necessarily true for LaTeX docs)
+ //determine the parent doc for each item (TODO:an item can only have one parent, not necessarily true for LaTeX docs)
const TQStringList *deps;
TQString dep;
@@ -522,7 +522,7 @@ void KileProject::buildProjectTree()
}
- //use the dependencies list of the documentinfo object to determine the tqparent
+ //use the dependencies list of the documentinfo object to determine the parent
it.toFirst();
while (it.current())
@@ -550,12 +550,12 @@ void KileProject::buildProjectTree()
}
- //make a list of all the root items (items with tqparent == 0)
+ //make a list of all the root items (items with parent == 0)
m_rootItems.clear();
it.toFirst();
@@ -728,10 +728,10 @@ bool KileProject::contains(const KileDocument::Info *info)
KileProjectItem *KileProject::rootItem(KileProjectItem *item) const
{
- //find the root item (i.e. the eldest tqparent)
+ //find the root item (i.e. the eldest parent)
KileProjectItem *root = item;